# python-toolz v0.1.7

> [Zguillez](https://zguillez.io) | Guillermo de la Iglesia

## Python helpers

# Getting Started

## Install

```
pip install --upgrade python-toolz
```

# Usage

```
from python_toolz import helper as ztools

ztools.log("test")
```

```
db = ztools.database({
    'conn': os.environ['DB_HOST'],
    'database': os.environ['DB_NAME'],
    'user': os.environ['DB_USER'],
    'password': os.environ['DB_PASS']
})
data = db.sql("SELECT id, name FROM template ORDER BY id ASC LIMIT 0,5")
db.close()
print(data[0])
```

```
data = db.dict("SELECT id, name FROM template ORDER BY id ASC LIMIT 0,5", ['id', 'name'])
db.close()
print(data[0]['name'])
```

# Contributing and issues

Contributors are welcome, please fork and send pull requests! If you have any ideas on how to make this project better
then please submit an issue or [email](mailto:guillermo@delaiglesia.email) me.

# License

©2023 Zguillez.IO

Original code licensed under [MIT](https://en.wikipedia.org/wiki/MIT_License) Open Source projects used within this
project retain their original licenses.

# Changelog

### v0.1.0 (February 11, 2023)

* Initial commit
